@@ -1,7 +1,9 @@
 /* imlib.c
 
 Copyright 1999-2000 Tom Gilbert
+Copyright 2020      ideal <idealities@gmail.com>
 Copyright 2020      Sean Brennan <zettix1@gmail.com>
+Copyright 2020      spycapitan <spycapitan@protonmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -34,17 +36,28 @@ Colormap cm;
 int depth;
 Window root = 0;
 
+
+/* atexit register func. */
+static void uninit_x_and_imlib(void)
+{
+  if (disp) XCloseDisplay(disp);
+}
+
+
 void
 init_x_and_imlib(char *dispstr, int screen_num)
 {
    disp = XOpenDisplay(dispstr);
    if (!disp) {
       fprintf(stderr, "Can't open X display. It *is* running, yeah? [");
-      fprintf(stderr, "%s", dispstr);
-      fprintf(stderr, "]");
+      fprintf(stderr, "%s", dispstr ? dispstr :
+              (getenv("DISPLAY") ? getenv("DISPLAY") : "NULL"));
+      fprintf(stderr, "]\n");
       exit(EXIT_FAILURE);
    }
 
+   atexit(uninit_x_and_imlib);
+
    if (screen_num)
       scr = ScreenOfDisplay(disp, screen_num);
    else
