@@ -10,6 +10,7 @@ Copyright 2019      Daniel T. Borelli <danieltborelli@gmail.com>
 Copyright 2019      Jade Auer <jade@trashwitch.dev>
 Copyright 2020      Hinigatsu <hinigatsu@protonmail.com>
 Copyright 2020      Sean Brennan <zettix1@gmail.com>
+Copyright 2020      spycapitan <spycapitan@protonmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -72,6 +73,8 @@ main(int argc,
     scrot_do_delay();
     if (opt.multidisp) {
       image = scrot_grab_shot_multi();
+    } else if (opt.stack) {
+      image = scrot_grab_stack_windows();
     } else {
       image = scrot_grab_shot();
     }
@@ -807,6 +810,74 @@ scrot_find_window_by_property(Display * display,
   return (child);
 }
 
+Imlib_Image
+scrot_grab_stack_windows(void)
+{
+    if (XGetSelectionOwner(disp, XInternAtom(disp, "_NET_WM_CM_S0", False)) == None) {
+        fprintf(stderr, "Composite Manager is not running, required to use this option.\n");
+        exit(EXIT_FAILURE);
+    }
+
+    unsigned long nitems_return;
+    unsigned long bytes_after_return;
+    unsigned char *prop_return;
+    long long_offset = 0L;
+    long long_length = ~0L;
+    Bool delete      = False;
+    int actual_format_return;
+    Atom actual_type_return;
+    gib_list *list_images   = NULL;
+    Imlib_Image im          = NULL;
+    XImage *ximage          = NULL;
+    XWindowAttributes attr;
+
+#define EWMH_CLIENT_LIST "_NET_CLIENT_LIST" // spec EWMH
+
+    Atom atom_prop = XInternAtom(disp, EWMH_CLIENT_LIST, False);
+    Atom atom_type = AnyPropertyType;
+
+    int result = XGetWindowProperty(disp, root, atom_prop, long_offset, long_length,
+                                delete, atom_type, &actual_type_return, &actual_format_return,
+                                &nitems_return, &bytes_after_return, &prop_return);
+
+    if (result != Success || nitems_return == 0) {
+       fprintf(stderr, "Failed XGetWindowProperty: " EWMH_CLIENT_LIST "\n");
+       exit(EXIT_FAILURE);
+    }
+
+    XCompositeRedirectSubwindows(disp, root, CompositeRedirectAutomatic);
+
+    for (int i = 0; i < nitems_return; i++) {
+
+        Window win = *((Window*)prop_return + i);
+
+        if (0 == XGetWindowAttributes(disp, win, &attr)) {
+           fprintf(stderr, "Failed XGetWindowAttributes\n");
+           exit(EXIT_FAILURE);
+        }
+
+        /* Only visible windows */
+        if (attr.map_state != IsViewable) {
+            continue;
+        }
+
+        ximage = XGetImage(disp, win, 0, 0, attr.width, attr.height, AllPlanes, ZPixmap);
+
+        if (ximage == NULL) {
+            fprintf(stderr, "Failed XGetImage: Window id 0x%lx.\n", win);
+            exit(EXIT_FAILURE);
+        }
+
+        im = imlib_create_image_from_ximage(ximage, NULL, attr.x, attr.y, attr.width, attr.height, 1);
+
+        XFree(ximage);
+
+        list_images = gib_list_add_end(list_images, im);
+    }
+
+    return stalk_image_concat(list_images);
+}
+
 Imlib_Image
 scrot_grab_shot_multi(void)
 {
@@ -821,8 +892,6 @@ scrot_grab_shot_multi(void)
   if (screens < 2)
     return scrot_grab_shot();
 
-  dispstr = DisplayString(disp);
-
   subdisp = gib_estrdup(DisplayString(disp));
 
   for (i = 0; i < screens; i++) {
