@@ -12,6 +12,7 @@ Copyright 2019      Daniel Lublin <daniel@lublin.se>
 Copyright 2019      Daniel T. Borelli <danieltborelli@gmail.com>
 Copyright 2019      Jade Auer <jade@trashwitch.dev>
 Copyright 2020      Sean Brennan <zettix1@gmail.com>
+Copyright 2020      spycapitan <spycapitan@protonmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -52,6 +53,7 @@ init_parse_options(int argc, char **argv)
    opt.line_width = 1;
    opt.line_color = NULL;
    opt.display = NULL;
+   opt.stack = 0;
 
    /* Parse the cmdline args */
    scrot_parse_option_array(argc, argv);
@@ -64,7 +66,9 @@ options_parse_required_number(char *str)
    int ret = 0;
    errno = 0;
 
-   ret = strtol(str, &end, 10);
+   if (str != NULL) {
+      ret = strtol(str, &end, 10);
+   }
 
    if (str == end) {
       fprintf(stderr, "the option is not a number: %s\n", end);
@@ -157,7 +161,7 @@ options_parse_line(char *optarg)
 static void
 scrot_parse_option_array(int argc, char **argv)
 {
-   static char stropts[] = "a:ofpbcd:e:hmq:st:uv+:zn:l:D:";
+   static char stropts[] = "a:ofpbcd:e:hmq:st:uv+:zn:l:D:k";
 
    static struct option lopts[] = {
       /* actions */
@@ -173,6 +177,7 @@ scrot_parse_option_array(int argc, char **argv)
       {"pointer", 0, 0, 'p'},
       {"freeze", 0, 0, 'f'},
       {"overwrite", 0, 0, 'o'},
+      {"stack", 0, 0,'k'},
       /* toggles */
       {"thumb", 1, 0, 't'},
       {"delay", 1, 0, 'd'},
@@ -255,6 +260,9 @@ scrot_parse_option_array(int argc, char **argv)
         case 'l':
            options_parse_line(optarg);
            break;
+        case 'k':
+           opt.stack = 1;
+        break;
         case '?':
            exit(EXIT_FAILURE);
         default:
@@ -334,7 +342,19 @@ options_parse_autoselect(char *optarg)
      opt.autoselect_y=dimensions[1];
      opt.autoselect_w=dimensions[2];
      opt.autoselect_h=dimensions[3];
+
+     if (i != 4)
+     {
+       fprintf(stderr, "option 'autoselect' require 4 arguments\n");
+       exit(EXIT_FAILURE);
+     }
    }
+   else {
+       fprintf(stderr, "invalid format for option -- 'autoselect'\n");
+       exit(EXIT_FAILURE);
+   }
+
+
 }
 
 void
@@ -454,7 +474,8 @@ show_usage(void)
            "                            See SELECTION STYLE\n"
            "  -n, --note                Draw a text note.\n"
            "                            See NOTE FORMAT\n"
-
+           "  -k, --stack               Capture stack/overlaped windows and join them together.\n"
+           "                            A running Composite Manager is needed.\n"
            "\n" "  SPECIAL STRINGS\n"
            "  Both the --exec and filename parameters can take format specifiers\n"
            "  that are expanded by " SCROT_PACKAGE " when encountered.\n"
