@@ -7,7 +7,8 @@ Copyright 2009      James Cameron <quozl@us.netrek.org>
 Copyright 2010      Ibragimov Rinat <ibragimovrinat@mail.ru>
 Copyright 2017      Stoney Sauce <stoneysauce@gmail.com>
 Copyright 2019      Daniel T. Borelli <danieltborelli@gmail.com>
-Copýright 2020      Sean Brennan <zettix1@gmail.com>
+Copyright 2020      Sean Brennan <zettix1@gmail.com>
+Copyright 2020      spycapitan <spycapitan@protonmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -52,6 +53,7 @@ struct __scrotoptions
    int overwrite;
    int line_style;
    int line_width;
+   int stack;
    char *line_color;
    char *output_file;
    char *thumb_file;
