@@ -5,7 +5,9 @@ Copyright 1999-2000 Tom Gilbert <tom@linuxbrit.co.uk,
                                   scrot_sucks@linuxbrit.co.uk>
 Copyright 2009      James Cameron <quozl@us.netrek.org>
 Copyright 2019      Daniel T. Borelli <danieltborelli@gmail.com>
+Copyright 2020      Jeroen Roovers <jer@gentoo.org>
 Copyright 2020      Hinigatsu <hinigatsu@protonmail.com>
+Copyright 2020      spycapitan <spycapitan@protonmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -39,7 +41,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <X11/Xresource.h>
 #include <X11/cursorfont.h>
 #include <X11/extensions/Xfixes.h>
-#include <X11/Xcursor/Xcursor.h>
+#include <X11/extensions/Xcomposite.h>
 
 #include <stdio.h>
 #include <string.h>
@@ -94,6 +96,7 @@ char *im_printf(char *str, struct tm *tm,
                 char *filename_im, char *filename_thumb,
                 Imlib_Image im);
 Imlib_Image scrot_grab_shot_multi(void);
+Imlib_Image scrot_grab_stack_windows(void);
 Imlib_Image stalk_image_concat(gib_list *images);
 
 void scrot_grab_mouse_pointer(const Imlib_Image image,
